@@ -624,8 +624,8 @@ class WordToken(models.Model):
     def getPreviousContext(self,window=10):
         context = []
         prev = self.getPreviousWord()
-        durSum = 0.0
-        while durSum < window:
+        durSum = prev.getDuration()
+        while durSum <= window:
             if prev is None:
                 break
             context.append(prev)
@@ -636,12 +636,13 @@ class WordToken(models.Model):
     def getFollowingContext(self,window=10):
         context = []
         foll = self.getFollowingWord()
-        durSum = 0.0
-        while durSum < window:
+        durSum = foll.getDuration()
+        while durSum <= window:
             if foll is None:
                 break
             context.append(foll)
             foll = foll.getFollowingWord()
+            durSum += foll.getDuration()
         return context
 
     def getRecentRepetition(self):
