@@ -13,6 +13,7 @@ from celery.utils.log import get_task_logger
 
 from django.db.models import Q
 from django.core.management import call_command
+from django.conf import settings
 
 from .models import WordType,WordToken,Dialog,SegmentType,SegmentToken,Speaker,Category,Underlying
 from .utils import fetch_buckeye_resource,fetch_media_resource,loadFile
@@ -323,6 +324,8 @@ def doBasicAnalysis(logfilename,form):
     #words = words.filter(WordType__StressVowel__in = vows)
     words = words.filter(WordType__Label__in = goodWords).order_by('Dialog')
     sp = [str(x) for x in Speaker.objects.all() if str(x) != 's35']
+    if settings.DEBUG:
+        sp = Speaker.objects.filter(Number = 's03')
     #for s in sp:
     #    AnalyzeSpeaker.delay(words, s,form)
     res = chord((AnalyzeSpeaker.s(words, s, form) for s in sp), combineResults.s())()
